@@ -148,13 +148,21 @@ class User(EditCourses):
 		Initialize().new_or_existing()
 		
 	def load_user(self, name):
-		with open(name + ".txt") as file_name:
-			global user_data
-			user_data = json.load(file_name)
+		while True:
+			try:
+				with open(name + ".txt") as file_name:
+					global user_data
+					user_data = json.load(file_name)
+			except IOError:
+				print "User \"%s\" does not exist." % name
+
+				print "...Navigating Title Screen..."
+				Initialize().new_or_existing()
 			
-			# This part could be made more efficient. The "name" in user_data and the name entered when loading will always be the exact same. A "name" 				key is unecessary.
-			global username
-			username = user_data["name"]
+			
+		# This part could be made more efficient. The "name" in user_data and the name entered when loading will always be the exact same. A "name" 				key is unecessary.
+		global username
+		username = user_data["name"]
 			
 		MainMenu(username).menu(username)
 			
@@ -316,3 +324,5 @@ class Required(object):
 		
 		raw_input("\nPress ENTER to return to the Main Menu: ")
 		MainMenu(username).menu(username)
+
+Initialize().new_or_existing()
